@@ -1,10 +1,15 @@
 """Activate, get and deactivate translations."""
+
 from __future__ import annotations
 
 import gettext as gettext_module
-import os.path
 from threading import local
 
+TYPE_CHECKING = False
+if TYPE_CHECKING:
+    import os
+    import pathlib
+
 __all__ = ["activate", "deactivate", "decimal_separator", "thousands_separator"]
 
 _TRANSLATIONS: dict[str | None, gettext_module.NullTranslations] = {
@@ -31,14 +36,16 @@ _DECIMAL_SEPARATOR = {
 }
 
 
-def _get_default_locale_path() -> str | None:
-    try:
-        if __file__ is None:
-            return None
-        return os.path.join(os.path.dirname(__file__), "locale")
-    except NameError:
+def _get_default_locale_path() -> pathlib.Path | None:
+    package = __spec__ and __spec__.parent
+    if not package:
         return None
 
+    import importlib.resources
+
+    with importlib.resources.as_file(importlib.resources.files(package)) as pkg:
+        return pkg / "locale"
+
 
 def get_translation() -> gettext_module.NullTranslations:
     try:
@@ -47,14 +54,17 @@ def get_translation() -> gettext_module.NullTranslations:
         return _TRANSLATIONS[None]
 
 
-def activate(locale: str, path: str | None = None) -> gettext_module.NullTranslations:
+def activate(
+    locale: str | None, path: str | os.PathLike[str] | None = None
+) -> gettext_module.NullTranslations:
     """Activate internationalisation.
 
     Set `locale` as current locale. Search for locale in directory `path`.
 
     Args:
-        locale (str): Language name, e.g. `en_GB`.
-        path (str): Path to search for locales.
+        locale (str | None): Language name, e.g. `en_GB`. If `None`, defaults to no
+            transaltion. Similar to calling ``deactivate()``.
+        path (str | pathlib.Path): Path to search for locales.
 
     Returns:
         dict: Translations.
@@ -62,6 +72,10 @@ def activate(locale: str, path: str | None = None) -> gettext_module.NullTransla
     Raises:
         Exception: If humanize cannot find the locale folder.
     """
+    if locale is None or locale.startswith("en"):
+        _CURRENT.locale = None
+        return _TRANSLATIONS[None]
+
     if path is None:
         path = _get_default_locale_path()
 
