@@ -2,29 +2,29 @@
 
 from __future__ import annotations
 
-import math
-import re
-import sys
-from typing import TYPE_CHECKING
-
 from .i18n import _gettext as _
 from .i18n import _ngettext, decimal_separator, thousands_separator
 from .i18n import _ngettext_noop as NS_
 from .i18n import _pgettext as P_
 
+TYPE_CHECKING = False
 if TYPE_CHECKING:
+    import sys
+
     if sys.version_info >= (3, 10):
         from typing import TypeAlias
     else:
         from typing_extensions import TypeAlias
 
-# This type can be better defined by typing.SupportsInt, typing.SupportsFloat
-# but that's a Python 3.8 only typing option.
-NumberOrString: TypeAlias = "float | str"
+    # This type can be better defined by typing.SupportsFloat
+    # but that's a Python 3.8 only typing option.
+    NumberOrString: TypeAlias = float | str
 
 
 def _format_not_finite(value: float) -> str:
     """Utility function to handle infinite and nan cases."""
+    import math
+
     if math.isnan(value):
         return "NaN"
     if math.isinf(value) and value < 0:
@@ -71,6 +71,8 @@ def ordinal(value: NumberOrString, gender: str = "male") -> str:
     Returns:
         str: Ordinal string.
     """
+    import math
+
     try:
         if not math.isfinite(float(value)):
             return _format_not_finite(float(value))
@@ -142,6 +144,8 @@ def intcomma(value: NumberOrString, ndigits: int | None = None) -> str:
     Returns:
         str: String containing commas every three digits.
     """
+    import math
+
     thousands_sep = thousands_separator()
     decimal_sep = decimal_separator()
     try:
@@ -165,6 +169,8 @@ def intcomma(value: NumberOrString, ndigits: int | None = None) -> str:
     else:
         orig = str(value)
     orig = orig.replace(".", decimal_sep)
+    import re
+
     while True:
         new = re.sub(r"^(-?\d+)(\d{3})", rf"\g<1>{thousands_sep}\g<2>", orig)
         if orig == new:
@@ -224,6 +230,8 @@ def intword(value: NumberOrString, format: str = "%.1f") -> str:
         str: Friendly text representation as a string, unless the value passed could not
             be coaxed into an `int`.
     """
+    import math
+
     try:
         if not math.isfinite(float(value)):
             return _format_not_finite(float(value))
@@ -291,6 +299,8 @@ def apnumber(value: NumberOrString) -> str:
             returns a string unless the value was not `int`-able, then `str(value)`
             is returned.
     """
+    import math
+
     try:
         if not math.isfinite(float(value)):
             return _format_not_finite(float(value))
@@ -352,6 +362,8 @@ def fractional(value: NumberOrString) -> str:
     Returns:
         str: Fractional number as a string.
     """
+    import math
+
     try:
         number = float(value)
         if not math.isfinite(number):
@@ -406,6 +418,8 @@ def scientific(value: NumberOrString, precision: int = 2) -> str:
     Returns:
         str: Number in scientific notation z.wq x 10ⁿ.
     """
+    import math
+
     exponents = {
         "0": "⁰",
         "1": "¹",
@@ -429,6 +443,8 @@ def scientific(value: NumberOrString, precision: int = 2) -> str:
     n = fmt.format(value)
     part1, part2 = n.split("e")
     # Remove redundant leading '+' or '0's (preserving the last '0' for 10⁰).
+    import re
+
     part2 = re.sub(r"^\+?(\-?)0*(.+)$", r"\1\2", part2)
 
     new_part2 = []
@@ -487,6 +503,8 @@ def clamp(
             will be prepended with a token indicating as such.
 
     """
+    import math
+
     if value is None:
         return None
 
@@ -550,6 +568,8 @@ def metric(value: float, unit: str = "", precision: int = 3) -> str:
     Returns:
         str:
     """
+    import math
+
     if not math.isfinite(value):
         return _format_not_finite(value)
     exponent = int(math.floor(math.log10(abs(value)))) if value != 0 else 0
@@ -564,7 +584,7 @@ def metric(value: float, unit: str = "", precision: int = 3) -> str:
         ordinal_ = "mμnpfazyrq"[(-exponent - 1) // 3]
     else:
         ordinal_ = ""
-    value_ = format(value, ".%if" % max(0, precision - (exponent % 3) - 1))
+    value_ = format(value, f".{int(max(0, precision - exponent % 3 - 1))}f")
     if not (unit or ordinal_) or unit in ("°", "′", "″"):
         space = ""
     else:
