@@ -1,15 +1,10 @@
-#!/usr/bin/env python
-
 """Time humanizing functions.
 
 These are largely borrowed from Django's `contrib.humanize`.
 """
+
 from __future__ import annotations
 
-import collections.abc
-import datetime as dt
-import math
-import typing
 from enum import Enum
 from functools import total_ordering
 
@@ -17,11 +12,17 @@ from .i18n import _gettext as _
 from .i18n import _ngettext
 from .number import intcomma
 
+TYPE_CHECKING = False
+if TYPE_CHECKING:
+    import datetime as dt
+    from collections.abc import Iterable
+    from typing import Any
+
 __all__ = [
+    "naturaldate",
+    "naturalday",
     "naturaldelta",
     "naturaltime",
-    "naturalday",
-    "naturaldate",
     "precisedelta",
 ]
 
@@ -37,13 +38,15 @@ class Unit(Enum):
     MONTHS = 6
     YEARS = 7
 
-    def __lt__(self, other: typing.Any) -> typing.Any:
+    def __lt__(self, other: Any) -> Any:
         if self.__class__ is other.__class__:
             return self.value < other.value
         return NotImplemented
 
 
 def _now() -> dt.datetime:
+    import datetime as dt
+
     return dt.datetime.now()
 
 
@@ -62,13 +65,13 @@ def _abs_timedelta(delta: dt.timedelta) -> dt.timedelta:
     return delta
 
 
-def _date_and_delta(
-    value: typing.Any, *, now: dt.datetime | None = None
-) -> tuple[typing.Any, typing.Any]:
+def _date_and_delta(value: Any, *, now: dt.datetime | None = None) -> tuple[Any, Any]:
     """Turn a value into a date and a timedelta which represents how long ago it was.
 
     If that's not possible, return `(None, value)`.
     """
+    import datetime as dt
+
     if not now:
         now = _now()
     if isinstance(value, dt.datetime):
@@ -105,12 +108,13 @@ def naturaldelta(
     Returns:
         str (str or `value`): A natural representation of the amount of time
             elapsed unless `value` is not datetime.timedelta or cannot be
-            converted to int. In that case, a `value` is returned unchanged.
+            converted to int (cannot be float due to 'inf' or 'nan').
+            In that case, a `value` is returned unchanged.
 
     Raises:
         OverflowError: If `value` is too large to convert to datetime.timedelta.
 
-    Examples
+    Examples:
         Compare two timestamps in a custom local timezone::
 
         import datetime as dt
@@ -122,30 +126,33 @@ def naturaldelta(
 
         assert naturaldelta(later - now) == "30 minutes"
     """
+    import datetime as dt
+
     tmp = Unit[minimum_unit.upper()]
     if tmp not in (Unit.SECONDS, Unit.MILLISECONDS, Unit.MICROSECONDS):
-        raise ValueError(f"Minimum unit '{minimum_unit}' not supported")
+        msg = f"Minimum unit '{minimum_unit}' not supported"
+        raise ValueError(msg)
     min_unit = tmp
 
     if isinstance(value, dt.timedelta):
         delta = value
     else:
         try:
-            value = int(value)
+            int(value)  # Explicitly don't support string such as "NaN" or "inf"
+            value = float(value)
             delta = dt.timedelta(seconds=value)
         except (ValueError, TypeError):
             return str(value)
 
     use_months = months
 
-    seconds = abs(delta.seconds)
-    days = abs(delta.days)
-    years = days // 365
-    days = days % 365
+    delta = abs(delta)
+    years = delta.days // 365
+    days = delta.days % 365
     num_months = int(days // 30.5)
 
     if not years and days < 1:
-        if seconds == 0:
+        if delta.seconds == 0:
             if min_unit == Unit.MICROSECONDS and delta.microseconds < 1000:
                 return (
                     _ngettext("%d microsecond", "%d microseconds", delta.microseconds)
@@ -162,24 +169,24 @@ def naturaldelta(
                 )
             return _("a moment")
 
-        if seconds == 1:
+        if delta.seconds == 1:
             return _("a second")
 
-        if seconds < 60:
-            return _ngettext("%d second", "%d seconds", seconds) % seconds
+        if delta.seconds < 60:
+            return _ngettext("%d second", "%d seconds", delta.seconds) % delta.seconds
 
-        if 60 <= seconds < 120:
+        if 60 <= delta.seconds < 120:
             return _("a minute")
 
-        if 120 <= seconds < 3600:
-            minutes = seconds // 60
+        if 120 <= delta.seconds < 3600:
+            minutes = delta.seconds // 60
             return _ngettext("%d minute", "%d minutes", minutes) % minutes
 
-        if 3600 <= seconds < 3600 * 2:
+        if 3600 <= delta.seconds < 3600 * 2:
             return _("an hour")
 
-        if 3600 < seconds:
-            hours = seconds // 3600
+        if 3600 < delta.seconds:
+            hours = delta.seconds // 3600
             return _ngettext("%d hour", "%d hours", hours) % hours
 
     elif years == 0:
@@ -244,7 +251,13 @@ def naturaltime(
     Returns:
         str: A natural representation of the input in a resolution that makes sense.
     """
+    import datetime as dt
+
+    value = _convert_aware_datetime(value)
+    when = _convert_aware_datetime(when)
+
     now = when or _now()
+
     date, delta = _date_and_delta(value, now=now)
     if date is None:
         return str(value)
@@ -261,6 +274,17 @@ def naturaltime(
     return str(ago % delta)
 
 
+def _convert_aware_datetime(
+    value: dt.datetime | dt.timedelta | float | None,
+) -> Any:
+    """Convert aware datetime to naive datetime and pass through any other type."""
+    import datetime as dt
+
+    if isinstance(value, dt.datetime) and value.tzinfo is not None:
+        value = dt.datetime.fromtimestamp(value.timestamp())
+    return value
+
+
 def naturalday(value: dt.date | dt.datetime, format: str = "%b %d") -> str:
     """Return a natural day.
 
@@ -269,6 +293,8 @@ def naturalday(value: dt.date | dt.datetime, format: str = "%b %d") -> str:
     formatted according to `format`.
 
     """
+    import datetime as dt
+
     try:
         value = dt.date(value.year, value.month, value.day)
     except AttributeError:
@@ -293,6 +319,8 @@ def naturalday(value: dt.date | dt.datetime, format: str = "%b %d") -> str:
 
 def naturaldate(value: dt.date | dt.datetime) -> str:
     """Like `naturalday`, but append a year for dates more than ~five months away."""
+    import datetime as dt
+
     try:
         value = dt.date(value.year, value.month, value.day)
     except AttributeError:
@@ -312,7 +340,7 @@ def _quotient_and_remainder(
     divisor: float,
     unit: Unit,
     minimum_unit: Unit,
-    suppress: collections.abc.Iterable[Unit],
+    suppress: Iterable[Unit],
 ) -> tuple[float, float]:
     """Divide `value` by `divisor` returning the quotient and remainder.
 
@@ -353,7 +381,7 @@ def _carry(
     ratio: float,
     unit: Unit,
     min_unit: Unit,
-    suppress: typing.Iterable[Unit],
+    suppress: Iterable[Unit],
 ) -> tuple[float, float]:
     """Return a tuple with two values.
 
@@ -386,7 +414,7 @@ def _carry(
     return value1, value2
 
 
-def _suitable_minimum_unit(min_unit: Unit, suppress: typing.Iterable[Unit]) -> Unit:
+def _suitable_minimum_unit(min_unit: Unit, suppress: Iterable[Unit]) -> Unit:
     """Return a minimum unit suitable that is not suppressed.
 
     If not suppressed, return the same unit:
@@ -409,14 +437,13 @@ def _suitable_minimum_unit(min_unit: Unit, suppress: typing.Iterable[Unit]) -> U
             if unit > min_unit and unit not in suppress:
                 return unit
 
-        raise ValueError(
-            "Minimum unit is suppressed and no suitable replacement was found"
-        )
+        msg = "Minimum unit is suppressed and no suitable replacement was found"
+        raise ValueError(msg)
 
     return min_unit
 
 
-def _suppress_lower_units(min_unit: Unit, suppress: typing.Iterable[Unit]) -> set[Unit]:
+def _suppress_lower_units(min_unit: Unit, suppress: Iterable[Unit]) -> set[Unit]:
     """Extend suppressed units (if any) with all units lower than the minimum unit.
 
     >>> from humanize.time import _suppress_lower_units, Unit
@@ -435,7 +462,7 @@ def _suppress_lower_units(min_unit: Unit, suppress: typing.Iterable[Unit]) -> se
 def precisedelta(
     value: dt.timedelta | int | None,
     minimum_unit: str = "seconds",
-    suppress: typing.Iterable[str] = (),
+    suppress: Iterable[str] = (),
     format: str = "%0.2f",
 ) -> str:
     """Return a precise representation of a timedelta.
@@ -578,7 +605,10 @@ def precisedelta(
     for unit, fmt in zip(reversed(Unit), fmts):
         singular_txt, plural_txt, fmt_value = fmt
         if fmt_value > 0 or (not texts and unit == min_unit):
-            fmt_txt = _ngettext(singular_txt, plural_txt, fmt_value)
+            _fmt_value = 2 if 1 < fmt_value < 2 else int(fmt_value)
+            fmt_txt = _ngettext(singular_txt, plural_txt, _fmt_value)
+            import math
+
             if unit == min_unit and math.modf(fmt_value)[0] > 0:
                 fmt_txt = fmt_txt.replace("%d", format)
             elif unit == YEARS:
